==> fred_regal-0.2.0-py3-none-any.whl: regal/search/contact.py <==
"""Client for SearchContact service."""
from datetime import datetime
from typing import Sequence

from fred_api.registry.contact import service_search_contact_grpc_pb2_grpc
from fred_api.registry.contact.service_search_contact_grpc_pb2 import SearchContactHistoryRequest, SearchContactRequest

from regal.contact import ContactHistoryId, ContactId

from .common import BaseSearchClient, SearchCurrentResult, SearchDecoder, SearchHistoryResult, SearchResults


class SearchContactClient(BaseSearchClient[ContactId, ContactHistoryId]):
    """SearchContact service gRPC client."""

    grpc_modules = (service_search_contact_grpc_pb2_grpc,)
    decoder_cls = SearchDecoder[ContactId, ContactHistoryId]
    service = 'SearchContact'
    limit_name = 'max_number_of_contacts'

    async def search_contact(
        self,
        query_values: Sequence[str],
        limit: int = None,
        searched_items: Sequence[str] = None
    ) -> SearchResults[SearchCurrentResult[ContactId]]:
        """Search for contacts based on query.

        Args:
            query_values: List of strings with searched values. Values can be substrings of some contacts fields.
            limit: Maximum number of returned best results.
            searched_items: List of contact fields that should be included in search.
                If ommited, all the fields will be searched.
        """
        return await self.search_object(
            request=SearchContactRequest(), method='search_contact',
            query_values=query_values, limit=limit, searched_items=searched_items,
        )

    async def search_contact_history(
        self,
        query_values: Sequence[str],
        limit: int = None,
        searched_items: Sequence[str] = None,
        start: datetime = None,
        end: datetime = None,
    ) -> SearchResults[SearchHistoryResult[ContactId, ContactHistoryId]]:
        """Search for contacts history versions based on query.

        Args:
            query_values: List of strings with searched values. Values can be substrings of some contact fields.
            limit: Maximum number of returned best results.
            searched_items: List of contact fields that should be included in search.
                If ommited, all the fields will be searched.
            start: Search contact throughout history starting with this datetime.
                If ommited, there is no lower limit on data age.
            end: Search contact throughout history ending with this datetime.
                If ommited, search all the way to current data.

        Raises:
            InvalidHistoryInterval: In case of invalid history interval.
        """
        return await self.search_object_history(
            request=SearchContactHistoryRequest(), method='search_contact_history',
            query_values=query_values, limit=limit, searched_items=searched_items, start=start, end=end,
        )

==> fred_regal-0.5.3-py3-none-any.whl: regal/search/contact.py <==
"""Client for SearchContact service."""
from datetime import datetime
from typing import Optional, Sequence

from fred_api.registry.contact import service_search_contact_grpc_pb2_grpc
from fred_api.registry.contact.service_search_contact_grpc_pb2 import SearchContactHistoryRequest, SearchContactRequest

from regal.contact import ContactHistoryId, ContactId

from .common import BaseSearchClient, SearchCurrentResult, SearchDecoder, SearchHistoryResult, SearchResults


class SearchContactClient(BaseSearchClient[ContactId, ContactHistoryId]):
    """SearchContact service gRPC client."""

    grpc_modules = (service_search_contact_grpc_pb2_grpc,)
    decoder_cls = SearchDecoder[ContactId, ContactHistoryId]
    service = 'SearchContact'
    limit_name = 'max_number_of_contacts'

    async def search_contact(
        self,
        query_values: Sequence[str],
        limit: Optional[int] = None,
        searched_items: Optional[Sequence[str]] = None
    ) -> SearchResults[SearchCurrentResult[ContactId]]:
        """Search for contacts based on query.

        Args:
            query_values: List of strings with searched values. Values can be substrings of some contacts fields.
            limit: Maximum number of returned best results.
            searched_items: List of contact fields that should be included in search.
                If ommited, all the fields will be searched.
        """
        return await self.search_object(
            request=SearchContactRequest(), method='search_contact',
            query_values=query_values, limit=limit, searched_items=searched_items,
        )

    async def search_contact_history(
        self,
        query_values: Sequence[str],
        limit: Optional[int] = None,
        searched_items: Optional[Sequence[str]] = None,
        start: Optional[datetime] = None,
        end: Optional[datetime] = None,
    ) -> SearchResults[SearchHistoryResult[ContactId, ContactHistoryId]]:
        """Search for contacts history versions based on query.

        Args:
            query_values: List of strings with searched values. Values can be substrings of some contact fields.
            limit: Maximum number of returned best results.
            searched_items: List of contact fields that should be included in search.
                If ommited, all the fields will be searched.
            start: Search contact throughout history starting with this datetime.
                If ommited, there is no lower limit on data age.
            end: Search contact throughout history ending with this datetime.
                If ommited, search all the way to current data.

        Raises:
            InvalidHistoryInterval: In case of invalid history interval.
        """
        return await self.search_object_history(
            request=SearchContactHistoryRequest(), method='search_contact_history',
            query_values=query_values, limit=limit, searched_items=searched_items, start=start, end=end,
        )
